'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }(); /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      * Mousewheel fix for certain browsers that just don't get it right
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      * Includes:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      * - fix for Safari 9 & 10:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *   in Safari 9 & 10 the default event is debounced, therefore broken.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *   The issue seems to occur due to the eleastic scroll and appeared with Safari 9
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *   which allows eleasic scroll in nested containers.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *   to fix this issue the `html` and/or `body` element usually has to be set to `overflow: hidden;`.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *   In many cases this comes with drawbacks or breaks other things.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *   Preventing the default event and then applying the `deltaY` to the `scrollTop`
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *   of the rootNode fixes the issue without other hacks.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *   - Attemt: prevent the mousewheel event and move the rootNode manually.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *   - Concern: impact on performance?
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      * @see  https://bugs.webkit.org/show_bug.cgi?id=149526
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      * @author  Gregor Adams <greg@pixelass.com>
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      * @license  MIT
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      */

var _detectBrowser = require('detect-browser');

var _detectBrowser2 = _interopRequireDefault(_detectBrowser);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * major browser version parsed from `detect-browser.js`'s result
 * @type {Number}
 */
var majorVersion = parseInt(_detectBrowser2.default.version.split('.')[0], 10);

/**
 * flag to find Safari 9 & 10 since it is known to have a bug
 * @see  https://bugs.webkit.org/show_bug.cgi?id=149526
 * @type {Boolean}
 */
var isSafari = _detectBrowser2.default.name === 'safari';
var isSafari9 = isSafari && majorVersion === 9;
var isSafari10 = isSafari && majorVersion === 10;

/**
 * flag to determine if we need to modify the `mousewheel` event
 * currently only Safari 9 & 10 gets this wrong.
 * @type {Boolean}
 */
var mouseNeedsHelp = isSafari9 || isSafari10;

/**
 * allows to create an instance that can be initialised and destroyed when needed
 * usually initialized on `document.ready` or when mounting a root component
 * and destroyed when a root component is unmounted
 */

var FixWheel = function () {
  function FixWheel(eventName) {
    _classCallCheck(this, FixWheel);

    this.eventName = eventName;
    this.fixWheel = this.fixWheel.bind(this);
  }

  /**
   * this method applys the fix for wheel events in browsers with faulty implementation
   * @param  {HTMLElement} rootNode a DOM node, usually `document.body` but can be any other root element.
   * @return {Boolean} returns `true` when applied, otherwise `false`.
   *                   Mainly used for debugging but can be used as a flag.
    */


  _createClass(FixWheel, [{
    key: 'init',
    value: function init(rootNode) {
      var force = arguments.length <= 1 || arguments[1] === undefined ? false : arguments[1];

      if (mouseNeedsHelp || force) {
        this.rootNode = rootNode;
        window.addEventListener(this.eventName, this.fixWheel, false);
        this.isFixed = true;
      }
      return this.isFixed;
    }

    /**
     * destroys the helper. removes the fix if it has been applied
     * @return {Boolean} should always return `false`.
     *                   Mainly used for debugging but can be used as a flag.
     */

  }, {
    key: 'destroy',
    value: function destroy() {
      if (this.isFixed) {
        window.removeEventListener(this.eventName, this.fixWheel);
        this.isFixed = false;
      }
      return this.isFixed;
    }

    /**
     * prevent the default event
     * @param  {Object} e mousewheel event
     */

  }, {
    key: 'preventDefault',
    value: function preventDefault(e) {
      e.preventDefault();
    }

    /**
     * the actual fix for the issue.
     * @param  {Object} e mousewheel event
     * @param  {Number} e.deltaY wheel delta on the y-axis (if undefined simply does nothing)
     */

  }, {
    key: 'fixWheel',
    value: function fixWheel(e) {
      this.preventDefault(e);
      this.rootNode.scrollTop += e.deltaY;
    }
  }]);

  return FixWheel;
}();

exports.default = FixWheel;