'use strict';

var _chai = require('chai');

var _ = require('..');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* global describe, it, window, document */
global.window = global.window || {
  addEventListener: function addEventListener(event, handler, useCapture) {},
  removeEventListener: function removeEventListener(event, handler, useCapture) {}
};
global.document = global.document || {
  body: {
    addEventListener: function addEventListener(event, handler, useCapture) {},
    removeEventListener: function removeEventListener(event, handler, useCapture) {},
    scrollTop: 0
  }
};

describe('FixWheel', function () {
  describe('Constructor', function () {
    it('is a constructor', function () {
      var fn = function fn() {
        var wheel = new _2.default('wheel');
        wheel.init(document.body);
      };
      (0, _chai.expect)(fn).to.not.throw();
    });

    it('can have multiple instances', function () {
      var wheel = new _2.default('wheel');
      var wheel2 = new _2.default('wheel');
      (0, _chai.expect)(wheel).to.be.instanceof(_2.default);
      (0, _chai.expect)(wheel2).to.be.instanceof(_2.default);
    });

    it('can be called with different events', function () {
      var fn1 = function fn1() {
        var wheel = new _2.default('wheel');
        wheel.init(document.body);
      };
      var fn2 = function fn2() {
        var wheel = new _2.default('mousewheel');
        wheel.init(document.body);
      };
      (0, _chai.expect)(fn1).to.not.throw();
      (0, _chai.expect)(fn2).to.not.throw();
    });
  });

  describe('Instances', function () {
    it('returns an object', function () {
      var wheel = new _2.default('wheel');
      (0, _chai.expect)(wheel).to.be.a('object');
    });

    it('returns methods', function () {
      var wheel = new _2.default('wheel');
      (0, _chai.expect)(wheel).itself.to.respondTo('init');
      (0, _chai.expect)(wheel).itself.to.respondTo('destroy');
      (0, _chai.expect)(wheel).itself.to.respondTo('preventDefault');
      (0, _chai.expect)(wheel).itself.to.respondTo('fixWheel');
      wheel.init(document.body, true);
      wheel.preventDefault({
        preventDefault: function preventDefault() {}
      });
      wheel.fixWheel({ deltaY: 0, preventDefault: function preventDefault() {}
      });
    });

    it('has an init method', function () {
      var wheel = new _2.default('wheel');
      (0, _chai.expect)(wheel).itself.to.respondTo('init');
      (0, _chai.expect)(wheel.init).to.be.a('function');
    });

    it('has an destroy method', function () {
      var wheel = new _2.default('wheel');
      (0, _chai.expect)(wheel).itself.to.respondTo('destroy');
      (0, _chai.expect)(wheel.destroy).to.be.a('function');
    });

    describe('Methods', function () {
      it('can be initialized', function () {
        var wheel = new _2.default('wheel');
        (0, _chai.expect)(wheel.init(document.body, true)).to.be.true;
      });

      it('can remain unapplied', function () {
        var wheel = new _2.default('wheel');
        (0, _chai.expect)(wheel.init(document.body)).to.be.falsy;
      });

      it('can be destroyed', function () {
        var wheel = new _2.default('wheel');
        (0, _chai.expect)(wheel.init(document.body, true)).to.be.true;
        (0, _chai.expect)(wheel.destroy()).to.be.false;
        (0, _chai.expect)(wheel.init(document.body)).to.be.falsy;
        (0, _chai.expect)(wheel.destroy()).to.be.false;
      });
    });
  });
});